methodByName method
Looks up a method by its short name, or null when absent.
Implementation
MethodDescriptor? methodByName(String name) {
for (final m in methods) {
if (m.name == name) return m;
}
return null;
}
Looks up a method by its short name, or null when absent.
MethodDescriptor? methodByName(String name) {
for (final m in methods) {
if (m.name == name) return m;
}
return null;
}