MethodKind enum
How an RPC method streams, matching protobuf's
client_streaming/server_streaming flag combination on a MethodProto.
Values
- unary → const MethodKind
-
One request, one response.
- serverStreaming → const MethodKind
-
One request, a stream of responses (
server_streaming = true). - clientStreaming → const MethodKind
-
A stream of requests, one response (
client_streaming = true). - bidiStreaming → const MethodKind
-
A stream of requests and a stream of responses (both flags
true).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MethodKind> - A constant List of the values in this enum, in order of their declaration.